import { Test, TestingModule } from "@nestjs/testing";
import request from 'supertest'
import { INestApplication } from "@nestjs/common";
import { AppModule } from "../infrastructure/modules";

describe('PapersController', () => {
    let app: INestApplication;

    beforeEach(async () => {
        const module: TestingModule = await Test.createTestingModule({
            imports: [AppModule],
        }).compile();

        app = module.createNestApplication();
        await app.init();
    });
    
    /**
     * Getting paper by its ID
     */
    it('Should be 404', () => {
        let uuid = 'eeeb2d01-8315-454e-b33f-3d6caa25db43';
        return request(app.getHttpServer())
            .get('/papers/' + uuid)
            .expect(404);
    });

    it('Should be 200', () => {
        let uuid = 'eeeb2d01-8315-454e-b33f-3d6caa25db42';
        return request(app.getHttpServer())
            .get('/papers/' + uuid)
            .expect(200);
    });

    /**
     * Getting paper by the given context
     */
    it('Should be 404', () => {
        let q_str = 'Explosion'; // Non-existing word in the test-paper
        return request(app.getHttpServer())
            .get('/papers/search?query=' + q_str)
            .expect(404);
    });

    it('Should be 200', () => {
        let q_str = 'Docker'; // Existing word in the test-paper
        return request(app.getHttpServer())
            .get('/papers/search?query=' + q_str)
            .expect(200);
    });
});